#
# spec file for package python-tinycss2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-tinycss2
Version:        1.4.0
Release:        1.4
Summary:        A tiny CSS parser
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/Kozea/tinycss2
Source:         https://files.pythonhosted.org/packages/source/t/tinycss2/tinycss2-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module webencodings >= 0.4}
# /SECTION
Requires:       python-webencodings >= 0.4
BuildArch:      noarch

%python_subpackages

%description
tinycss2 is a low-level CSS parser and generator written in Python:
it can parse strings, return objects representing tokens and blocks,
and generate CSS strings corresponding to these objects.

Based on the CSS Syntax Level 3 specification, tinycss2 knows the
grammar of CSS but doesn't know specific rules, properties or values
supported in various CSS modules.

%prep
%setup -q -n tinycss2-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/tinycss2
%{python_sitelib}/tinycss2-%{version}*-info

%changelog
* Tue Nov  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.4.0
  * Support CSS Color Level 4
* Thu May  2 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Support CSS nesting
  * Deprecate parse_declaration_list, use parse_blocks_contents
    instead
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Nov 17 2022 Ben Greiner <code@bnavigator.de>
- Clean specfile
- Requires Python >= 3.7, prevent failing build for 15.x targets
- Update Summary and Description
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.2.1
  * Fix tests included in the source tarball
  * Drop support of Python 3.6
  * Fix serialization of nested functions with no parameters
  * Don’t use pytest plugins by default
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Remove linter and code coverage check from packaging tests
* Fri Dec 17 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Tue Nov 23 2021 Axel Braun <axel.braun@gmx.de>
- version 1.1.1
  * build system switched to flit/toml
  * Drop support of Python 3.5, add support of Python 3.9.
  * Fix ResourceWarning in tests.
  * Use Python standard librarie’s HSL to RGB converter.
  * Use GitHub Actions for tests.
  * New code structure, new packaging, new documentation.
* Sat Jul 11 2020 Benjamin Greiner <code@bnavigator.de>
- switch of isort in testing. isort5 is out and breaks everything
* Sat May 16 2020 Benjamin Greiner <code@bnavigator.de>
- The fix for bsc#1130082 does not have an effect (anymore?).
  New version of flake8 raises more failures.
  Switch off flake8 tests by removing pytest-flake8 and the
  corresponding pytest argument.
- pytest-cov not needed
* Fri Apr 26 2019 pgajdos@suse.com
- version update to 1.0.2
  * Don't crash when indent tokens have no lowercase equivalent name
  * Parse "--" ident tokens correctly
  * Drop Python 2.7, 3.3 and 3.4 support.
  * Allow leading double dash syntax for ident tokens, allowing CSS variables to
    be parsed correctly.
  * Force tests to parse JSON files as UTF-8.
- python3 package only
* Fri Apr 12 2019 Matěj Cepl <mcepl@suse.com>
- bsc#1130082: Switch off FLAKE8-check test
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Initial version
